@@ -2,13 +2,13 @@
 #![allow(dead_code)]
 #![recursion_limit = "256"]
 
-pub use self::{transform_data::Feature, version::Version};
+use std::path::PathBuf;
+
 use anyhow::{Context, Error};
 use dashmap::DashMap;
 use once_cell::sync::Lazy;
 use serde::Deserialize;
 use st_map::StaticMap;
-use std::path::PathBuf;
 use swc_atoms::{js_word, JsWord};
 use swc_common::{
     chain,
@@ -24,6 +24,8 @@ use swc_ecma_transforms::{
 use swc_ecma_utils::prepend_stmts;
 use swc_ecma_visit::{Fold, FoldWith, VisitWith};
 
+pub use self::{transform_data::Feature, version::Version};
+
 #[macro_use]
 mod util;
 mod corejs2;
@@ -159,7 +161,19 @@ where
         }),
         true
     );
-    let pass = add!(pass, Classes, es2015::classes(comments));
+    let pass = add!(
+        pass,
+        Classes,
+        es2015::classes(
+            comments,
+            es2015::classes::Config {
+                constant_super: loose,
+                no_class_calls: loose,
+                set_class_methods: loose,
+                super_is_callable_constructor: loose,
+            }
+        )
+    );
     let pass = add!(
         pass,
         Spread,
